==> mingw-w64-clang-i686-osgworks-git-3.1.0.444-3-any.pkg.tar.zst: clang32/lib/osgworks-targets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "osgwControls" for configuration "Release"
set_property(TARGET osgwControls APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(osgwControls PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib/libosgwControls.dll.a"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "D:/a/msys64/clang32/lib/libosgGA.dll.a;D:/a/msys64/clang32/lib/libosgText.dll.a;D:/a/msys64/clang32/lib/libosgViewer.dll.a;D:/a/msys64/clang32/lib/libosgSim.dll.a;D:/a/msys64/clang32/lib/libosgDB.dll.a;D:/a/msys64/clang32/lib/libosgUtil.dll.a;D:/a/msys64/clang32/lib/libosg.dll.a;D:/a/msys64/clang32/lib/libOpenThreads.dll.a"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/libosgwControls.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS osgwControls )
list(APPEND _IMPORT_CHECK_FILES_FOR_osgwControls "${_IMPORT_PREFIX}/lib/libosgwControls.dll.a" "${_IMPORT_PREFIX}/bin/libosgwControls.dll" )

# Import target "osgwMx" for configuration "Release"
set_property(TARGET osgwMx APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(osgwMx PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib/libosgwMx.dll.a"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "D:/a/msys64/clang32/lib/libosgGA.dll.a;D:/a/msys64/clang32/lib/libosgText.dll.a;D:/a/msys64/clang32/lib/libosgViewer.dll.a;D:/a/msys64/clang32/lib/libosgSim.dll.a;D:/a/msys64/clang32/lib/libosgDB.dll.a;D:/a/msys64/clang32/lib/libosgUtil.dll.a;D:/a/msys64/clang32/lib/libosg.dll.a;D:/a/msys64/clang32/lib/libOpenThreads.dll.a;opengl32;glu32;osgwTools;D:/a/msys64/clang32/lib/libvrpn.dll.a"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/libosgwMx.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS osgwMx )
list(APPEND _IMPORT_CHECK_FILES_FOR_osgwMx "${_IMPORT_PREFIX}/lib/libosgwMx.dll.a" "${_IMPORT_PREFIX}/bin/libosgwMx.dll" )

# Import target "osgwQuery" for configuration "Release"
set_property(TARGET osgwQuery APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(osgwQuery PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib/libosgwQuery.dll.a"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "D:/a/msys64/clang32/lib/libosgGA.dll.a;D:/a/msys64/clang32/lib/libosgText.dll.a;D:/a/msys64/clang32/lib/libosgViewer.dll.a;D:/a/msys64/clang32/lib/libosgSim.dll.a;D:/a/msys64/clang32/lib/libosgDB.dll.a;D:/a/msys64/clang32/lib/libosgUtil.dll.a;D:/a/msys64/clang32/lib/libosg.dll.a;D:/a/msys64/clang32/lib/libOpenThreads.dll.a;opengl32;glu32;osgwTools"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/libosgwQuery.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS osgwQuery )
list(APPEND _IMPORT_CHECK_FILES_FOR_osgwQuery "${_IMPORT_PREFIX}/lib/libosgwQuery.dll.a" "${_IMPORT_PREFIX}/bin/libosgwQuery.dll" )

# Import target "osgwTools" for configuration "Release"
set_property(TARGET osgwTools APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(osgwTools PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib/libosgwTools.dll.a"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "D:/a/msys64/clang32/lib/libosgGA.dll.a;D:/a/msys64/clang32/lib/libosgText.dll.a;D:/a/msys64/clang32/lib/libosgViewer.dll.a;D:/a/msys64/clang32/lib/libosgSim.dll.a;D:/a/msys64/clang32/lib/libosgDB.dll.a;D:/a/msys64/clang32/lib/libosgUtil.dll.a;D:/a/msys64/clang32/lib/libosg.dll.a;D:/a/msys64/clang32/lib/libOpenThreads.dll.a;opengl32"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/libosgwTools.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS osgwTools )
list(APPEND _IMPORT_CHECK_FILES_FOR_osgwTools "${_IMPORT_PREFIX}/lib/libosgwTools.dll.a" "${_IMPORT_PREFIX}/bin/libosgwTools.dll" )

# Import target "osgdb_osgobjects" for configuration "Release"
set_property(TARGET osgdb_osgobjects APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(osgdb_osgobjects PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_RELEASE ""
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/osgdb_osgobjects.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS osgdb_osgobjects )
list(APPEND _IMPORT_CHECK_FILES_FOR_osgdb_osgobjects "${_IMPORT_PREFIX}/bin/osgdb_osgobjects.dll" )

# Import target "osgdb_osgwTools" for configuration "Release"
set_property(TARGET osgdb_osgwTools APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(osgdb_osgwTools PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_RELEASE ""
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/osgdb_osgwTools.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS osgdb_osgwTools )
list(APPEND _IMPORT_CHECK_FILES_FOR_osgdb_osgwTools "${_IMPORT_PREFIX}/bin/osgdb_osgwTools.dll" )

# Import target "osgdb_skeleton" for configuration "Release"
set_property(TARGET osgdb_skeleton APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(osgdb_skeleton PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_RELEASE ""
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/osgdb_skeleton.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS osgdb_skeleton )
list(APPEND _IMPORT_CHECK_FILES_FOR_osgdb_skeleton "${_IMPORT_PREFIX}/bin/osgdb_skeleton.dll" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> mingw-w64-clang-i686-osgworks-git-3.1.0.444-5-any.pkg.tar.zst: clang32/lib/osgworks-targets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "osgwControls" for configuration "Release"
set_property(TARGET osgwControls APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(osgwControls PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib/libosgwControls.dll.a"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "${_IMPORT_PREFIX}/lib/libosgGA.dll.a;${_IMPORT_PREFIX}/lib/libosgText.dll.a;${_IMPORT_PREFIX}/lib/libosgViewer.dll.a;${_IMPORT_PREFIX}/lib/libosgSim.dll.a;${_IMPORT_PREFIX}/lib/libosgDB.dll.a;${_IMPORT_PREFIX}/lib/libosgUtil.dll.a;${_IMPORT_PREFIX}/lib/libosg.dll.a;${_IMPORT_PREFIX}/lib/libOpenThreads.dll.a"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/libosgwControls.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS osgwControls )
list(APPEND _IMPORT_CHECK_FILES_FOR_osgwControls "${_IMPORT_PREFIX}/lib/libosgwControls.dll.a" "${_IMPORT_PREFIX}/bin/libosgwControls.dll" )

# Import target "osgwMx" for configuration "Release"
set_property(TARGET osgwMx APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(osgwMx PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib/libosgwMx.dll.a"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "${_IMPORT_PREFIX}/lib/libosgGA.dll.a;${_IMPORT_PREFIX}/lib/libosgText.dll.a;${_IMPORT_PREFIX}/lib/libosgViewer.dll.a;${_IMPORT_PREFIX}/lib/libosgSim.dll.a;${_IMPORT_PREFIX}/lib/libosgDB.dll.a;${_IMPORT_PREFIX}/lib/libosgUtil.dll.a;${_IMPORT_PREFIX}/lib/libosg.dll.a;${_IMPORT_PREFIX}/lib/libOpenThreads.dll.a;opengl32;glu32;osgwTools;${_IMPORT_PREFIX}/lib/libvrpn.dll.a"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/libosgwMx.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS osgwMx )
list(APPEND _IMPORT_CHECK_FILES_FOR_osgwMx "${_IMPORT_PREFIX}/lib/libosgwMx.dll.a" "${_IMPORT_PREFIX}/bin/libosgwMx.dll" )

# Import target "osgwQuery" for configuration "Release"
set_property(TARGET osgwQuery APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(osgwQuery PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib/libosgwQuery.dll.a"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "${_IMPORT_PREFIX}/lib/libosgGA.dll.a;${_IMPORT_PREFIX}/lib/libosgText.dll.a;${_IMPORT_PREFIX}/lib/libosgViewer.dll.a;${_IMPORT_PREFIX}/lib/libosgSim.dll.a;${_IMPORT_PREFIX}/lib/libosgDB.dll.a;${_IMPORT_PREFIX}/lib/libosgUtil.dll.a;${_IMPORT_PREFIX}/lib/libosg.dll.a;${_IMPORT_PREFIX}/lib/libOpenThreads.dll.a;opengl32;glu32;osgwTools"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/libosgwQuery.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS osgwQuery )
list(APPEND _IMPORT_CHECK_FILES_FOR_osgwQuery "${_IMPORT_PREFIX}/lib/libosgwQuery.dll.a" "${_IMPORT_PREFIX}/bin/libosgwQuery.dll" )

# Import target "osgwTools" for configuration "Release"
set_property(TARGET osgwTools APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(osgwTools PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib/libosgwTools.dll.a"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "${_IMPORT_PREFIX}/lib/libosgGA.dll.a;${_IMPORT_PREFIX}/lib/libosgText.dll.a;${_IMPORT_PREFIX}/lib/libosgViewer.dll.a;${_IMPORT_PREFIX}/lib/libosgSim.dll.a;${_IMPORT_PREFIX}/lib/libosgDB.dll.a;${_IMPORT_PREFIX}/lib/libosgUtil.dll.a;${_IMPORT_PREFIX}/lib/libosg.dll.a;${_IMPORT_PREFIX}/lib/libOpenThreads.dll.a;opengl32"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/libosgwTools.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS osgwTools )
list(APPEND _IMPORT_CHECK_FILES_FOR_osgwTools "${_IMPORT_PREFIX}/lib/libosgwTools.dll.a" "${_IMPORT_PREFIX}/bin/libosgwTools.dll" )

# Import target "osgdb_osgobjects" for configuration "Release"
set_property(TARGET osgdb_osgobjects APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(osgdb_osgobjects PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_RELEASE ""
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/osgdb_osgobjects.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS osgdb_osgobjects )
list(APPEND _IMPORT_CHECK_FILES_FOR_osgdb_osgobjects "${_IMPORT_PREFIX}/bin/osgdb_osgobjects.dll" )

# Import target "osgdb_osgwTools" for configuration "Release"
set_property(TARGET osgdb_osgwTools APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(osgdb_osgwTools PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_RELEASE ""
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/osgdb_osgwTools.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS osgdb_osgwTools )
list(APPEND _IMPORT_CHECK_FILES_FOR_osgdb_osgwTools "${_IMPORT_PREFIX}/bin/osgdb_osgwTools.dll" )

# Import target "osgdb_skeleton" for configuration "Release"
set_property(TARGET osgdb_skeleton APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(osgdb_skeleton PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_RELEASE ""
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/osgdb_skeleton.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS osgdb_skeleton )
list(APPEND _IMPORT_CHECK_FILES_FOR_osgdb_skeleton "${_IMPORT_PREFIX}/bin/osgdb_skeleton.dll" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
